from indicpy import get_executable_code

print(get_executable_code("indicpy/examples/kannada.pykn"))